
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef scout_MSG_LIB_H
#define scout_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "scoutType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  SCOUT_MBOX_NAME                  genomInstanceName("scout")

#define  SCOUT_MAX_RQST_SIZE              104

#define  SCOUT_MBOX_RQST_SIZE       \
 (BUF_SIZE(SCOUT_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  SCOUT_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  SCOUT_MAX_REPLY_SIZE             104

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  SCOUT_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(SCOUT_MAX_REPLY_SIZE) \
   + BUF_SIZE(SCOUT_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define SCOUT_CONNECTROBOT_RQST 0
#define SCOUT_GETCONNECTPARAMS_RQST 1
#define SCOUT_DISCONNECTROBOT_RQST 2
#define SCOUT_SETPOS_RQST 3
#define SCOUT_GETPOS_RQST 4
#define SCOUT_SETPOSDEV_RQST 5
#define SCOUT_STOP_RQST 6
#define SCOUT_TURN_RQST 7
#define SCOUT_GOTO_RQST 8
#define SCOUT_GOTOSPEED_RQST 9
#define SCOUT_TRACKSTART_RQST 10
#define SCOUT_TRACKSPEEDSTART_RQST 11
#define SCOUT_TRACKCONFIGSTART_RQST 12
#define SCOUT_TRACKEND_RQST 13
#define SCOUT_SONARSON_RQST 14
#define SCOUT_SONARSOFF_RQST 15
#define SCOUT_SETSONARSFIRINGORDER_RQST 16
#define SCOUT_GETSONARSFIRINGORDER_RQST 17
#define SCOUT_SETCMDDIST_RQST 18
#define SCOUT_GETCMDDIST_RQST 19
#define SCOUT_GETCMDCONFIG_RQST 20
#define SCOUT_SETCMDCONFIG_RQST 21
#define SCOUT_ABORT_RQST 22


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS scoutClientInit (CLIENT_ID *pClientId);

STATUS scoutClientEnd (CLIENT_ID clientId);

int scoutAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int scoutAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int scoutAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS scoutConnectRobotRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SCOUT_CONNECT_PARAM *(in_connectParam),
					 int replyTimeOut);

extern int scoutConnectRobotReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutConnectRobotRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SCOUT_CONNECT_PARAM *(in_connectParam), 
					
					int *activity, int *bilan);

extern int scoutConnectRobotRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SCOUT_CONNECT_PARAM *(in_connectParam), 
					
					int *activity,
					int *bilan);




extern STATUS scoutGetConnectParamsRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int scoutGetConnectParamsReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       SCOUT_CONNECT_PARAM *(out_connectParam),
			       int *bilan);

int scoutGetConnectParamsRqstAndRcv (CLIENT_ID clientId, 
				  
				 SCOUT_CONNECT_PARAM *(out_connectParam),
				 int *bilan);




extern STATUS scoutDisconnectRobotRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int scoutDisconnectRobotReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutDisconnectRobotRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int scoutDisconnectRobotRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS scoutSetPosRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SCOUT_SET_POS_STR *(in_setPos),
					 int replyTimeOut);

extern int scoutSetPosReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutSetPosRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SCOUT_SET_POS_STR *(in_setPos), 
					
					int *activity, int *bilan);

extern int scoutSetPosRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SCOUT_SET_POS_STR *(in_setPos), 
					
					int *activity,
					int *bilan);




extern STATUS scoutGetPosRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int scoutGetPosReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       SCOUT_SET_POS_STR *(out_setPos),
			       int *bilan);

int scoutGetPosRqstAndRcv (CLIENT_ID clientId, 
				  
				 SCOUT_SET_POS_STR *(out_setPos),
				 int *bilan);




extern STATUS scoutSetPosDevRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 SCOUT_ODO_VAR_STR *(in_odoError),
					 int replyTimeOut);

int scoutSetPosDevReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int scoutSetPosDevRqstAndRcv (CLIENT_ID clientId, 
				 SCOUT_ODO_VAR_STR *(in_odoError), 
				 
				 int *bilan);




extern STATUS scoutStopRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int scoutStopReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutStopRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int scoutStopRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS scoutTurnRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SCOUT_TURN *(in_turn),
					 int replyTimeOut);

extern int scoutTurnReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutTurnRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SCOUT_TURN *(in_turn), 
					
					int *activity, int *bilan);

extern int scoutTurnRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SCOUT_TURN *(in_turn), 
					
					int *activity,
					int *bilan);




extern STATUS scoutGoToRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SCOUT_REF_STR *(in_ref),
					 int replyTimeOut);

extern int scoutGoToReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutGoToRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SCOUT_REF_STR *(in_ref), 
					
					int *activity, int *bilan);

extern int scoutGoToRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SCOUT_REF_STR *(in_ref), 
					
					int *activity,
					int *bilan);




extern STATUS scoutGoToSpeedRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SCOUT_SPEED_REF_STR *(in_speedRef),
					 int replyTimeOut);

extern int scoutGoToSpeedReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutGoToSpeedRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SCOUT_SPEED_REF_STR *(in_speedRef), 
					
					int *activity, int *bilan);

extern int scoutGoToSpeedRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SCOUT_SPEED_REF_STR *(in_speedRef), 
					
					int *activity,
					int *bilan);




extern STATUS scoutTrackStartRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SCOUT_POSTER_NAME *(in_posterName),
					 int replyTimeOut);

extern int scoutTrackStartReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutTrackStartRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SCOUT_POSTER_NAME *(in_posterName), 
					
					int *activity, int *bilan);

extern int scoutTrackStartRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SCOUT_POSTER_NAME *(in_posterName), 
					
					int *activity,
					int *bilan);




extern STATUS scoutTrackSpeedStartRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SCOUT_POSTER_NAME *(in_posterName),
					 int replyTimeOut);

extern int scoutTrackSpeedStartReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutTrackSpeedStartRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SCOUT_POSTER_NAME *(in_posterName), 
					
					int *activity, int *bilan);

extern int scoutTrackSpeedStartRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SCOUT_POSTER_NAME *(in_posterName), 
					
					int *activity,
					int *bilan);




extern STATUS scoutTrackConfigStartRqstSend (CLIENT_ID clientId, int *pRqstId,
					 SCOUT_POSTER_NAME *(in_posterName),
					 int replyTimeOut);

extern int scoutTrackConfigStartReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutTrackConfigStartRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					SCOUT_POSTER_NAME *(in_posterName), 
					
					int *activity, int *bilan);

extern int scoutTrackConfigStartRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					SCOUT_POSTER_NAME *(in_posterName), 
					
					int *activity,
					int *bilan);




extern STATUS scoutTrackEndRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int scoutTrackEndReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int scoutTrackEndRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS scoutSonarsOnRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int scoutSonarsOnReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutSonarsOnRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int scoutSonarsOnRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS scoutSonarsOffRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int scoutSonarsOffReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int scoutSonarsOffRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int scoutSonarsOffRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS scoutSetSonarsFiringOrderRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 SCOUT_SONARS_FIRING_ORDER *(in_sonarsFiring),
					 int replyTimeOut);

int scoutSetSonarsFiringOrderReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int scoutSetSonarsFiringOrderRqstAndRcv (CLIENT_ID clientId, 
				 SCOUT_SONARS_FIRING_ORDER *(in_sonarsFiring), 
				 
				 int *bilan);




extern STATUS scoutGetSonarsFiringOrderRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int scoutGetSonarsFiringOrderReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       SCOUT_SONARS_FIRING_ORDER *(out_sonarsFiring),
			       int *bilan);

int scoutGetSonarsFiringOrderRqstAndRcv (CLIENT_ID clientId, 
				  
				 SCOUT_SONARS_FIRING_ORDER *(out_sonarsFiring),
				 int *bilan);




extern STATUS scoutSetCmdDistRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 double *(in_distPoint),
					 int replyTimeOut);

int scoutSetCmdDistReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int scoutSetCmdDistRqstAndRcv (CLIENT_ID clientId, 
				 double *(in_distPoint), 
				 
				 int *bilan);




extern STATUS scoutGetCmdDistRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int scoutGetCmdDistReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       double *(out_distPoint),
			       int *bilan);

int scoutGetCmdDistRqstAndRcv (CLIENT_ID clientId, 
				  
				 double *(out_distPoint),
				 int *bilan);




extern STATUS scoutGetCmdConfigRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int scoutGetCmdConfigReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       SCOUT_CMD_PARAM_STR *(out_cmd),
			       int *bilan);

int scoutGetCmdConfigRqstAndRcv (CLIENT_ID clientId, 
				  
				 SCOUT_CMD_PARAM_STR *(out_cmd),
				 int *bilan);




extern STATUS scoutSetCmdConfigRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 SCOUT_CMD_PARAM_STR *(in_cmd),
					 int replyTimeOut);

int scoutSetCmdConfigReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int scoutSetCmdConfigRqstAndRcv (CLIENT_ID clientId, 
				 SCOUT_CMD_PARAM_STR *(in_cmd), 
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* scout_MSG_LIB_H */

